@@ -31,6 +31,12 @@ class Collection:
         else:
             self._client = firestore_client
 
+        if issubclass(self.schema, BaseModel):
+            schema_pydantic = self.schema.schema()
+            self.schema_props = schema_pydantic.get('properties', {})
+        else:
+            self.schema_props = None
+
     @property
     def name(self):
         return self.schema.__name__
@@ -69,8 +75,10 @@ class Collection:
                limit: Optional[int] = None,
                order_by: Optional[List[Tuple[str, OrderByDirection]]] = []
                ) -> List[Any]:
+        # Parse condition values based on attribute type
+        conditions = self._parse_conditions(conditions)
+
         # Sanity checks
-        conditions = list(conditions)
         operators = [x[1].lower() for x in conditions]
         operator_counts = Counter(operators)
         unique_operators = list(operator_counts.keys())
@@ -207,7 +215,8 @@ class Collection:
 
     def update(self,
                doc: Union[BaseModel, dict],
-               owner: Optional[str] = None) -> None:
+               owner: Optional[str] = None,
+               force: Optional[bool] = False) -> None:
         if isinstance(doc, BaseModel) and not isinstance(doc, self.schema):
             raise ValueError(f"Invalid schema used for provided document: {doc}")
 
@@ -224,7 +233,7 @@ class Collection:
         doc.updated_at = datetime.utcnow()
 
         if isinstance(doc, SchemaWithOwner):
-            if owner is None and self.force_ownership:
+            if not force and (owner is None and self.force_ownership):
                 raise ValueError(f"An `owner` must be defined for collection {self.name}")
             doc.updated_by = owner
 
@@ -237,6 +246,8 @@ class Collection:
 
         # The `merge` mergeds the new data with any existing document
         # to avoid overwriting entire documents.
+        # TODO: Use `doc_ref.update(...)` instead
+        # See https://googleapis.dev/python/firestore/latest/document.html?highlight=update#google.cloud.firestore_v1.document.DocumentReference.update
         doc_ref.set(doc, merge=True)
 
     def insert(self,
@@ -279,10 +290,13 @@ class Collection:
 
         return self.schema(**{**doc.to_dict(), 'id': doc.id})
 
-    def delete(self, id: str, owner: Optional[str] = None) -> None:
+    def delete(self,
+               id: str,
+               owner: Optional[str] = None,
+               force: Optional[bool] = False) -> None:
         # Set updated by and time before deleting to trigger change
         if issubclass(self.schema, SchemaWithOwner):
-            if owner is None and self.force_ownership:
+            if not force and (owner is None and self.force_ownership):
                 raise ValueError(f"An `owner` must be defined for collection {self.name}")
 
             if owner is not None:
@@ -309,3 +323,24 @@ class Collection:
             except NotFound:
                 # No document with given unique key found
                 pass
+
+    def _parse_conditions(self, conditions: List[Tuple[str, str, Any]]) -> List[Tuple[str, str, Any]]:
+        conditions = list(conditions)
+        conditions_parsed = []
+        if self.schema_props is not None:
+            for attribute, operator, value in conditions:
+                attr_props = self.schema_props.get(attribute, {})
+                any_of = attr_props.get('anyOf', [])
+
+                # Check if schema is a datetime
+                if any((
+                    x.get('format') == 'date-time'
+                    for x in any_of
+                )):
+                    if type(value) == str:
+                        try:
+                            value = datetime.fromisoformat(value)
+                        except ValueError:
+                            pass
+                conditions_parsed.append((attribute, operator, value))
+        return conditions_parsed
